@@ -6,7 +6,6 @@ from pywood.decorators import event, events, no_events
 from pywood.events import BaseEvent
 from pywood.states import BaseState
 
-
 class Event1(BaseEvent):
     @staticmethod
     def happened(update=None) -> bool:
@@ -112,16 +111,19 @@ class TestStateMethods(unittest.TestCase):
         state = State()
         state._traverse_handlers('update', 'state_data')
 
-    def test_class_name(self):
+    def test_inst_classname(self):
         class MyCustomState(BaseState):
             pass
 
         state = MyCustomState()
         self.assertEqual(state.inst_classname, 'MyCustomState')
 
+
     def test_classname(self):
         class MyCustomState(BaseState):
             pass
         self.assertEqual(MyCustomState.classname(), 'MyCustomState')
 
 
+
+
